System.register(['./generated-main2.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('default', module.l);
		}],
		execute: (function () {



		})
	};
}));
